<?php
/**
 * Initialize the custom theme options.
 */
add_action( 'init', 'custom_theme_options' );

// add_filter( 'ot_show_pages', '__return_true' );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {
	
	// OptionTree is not loaded yet, or this is not an admin request.
	if ( ! function_exists( 'ot_settings_id' ) || ! is_admin() ) {
		return false;
	}
	
	// Get a copy of the saved settings array.
	$saved_settings = get_option( ot_settings_id(), array() );

	if ( function_exists( 'ot_get_option' ) ) {
		$currency_sym = ot_get_option( 'mata_uang' ) ?: 'Rp';  
	}
	
	// Custom settings array that will eventually be passes to the OptionTree Settings API Class.
	$custom_settings = array(
		'sections'        => array(
			array(
				'id'    => 'info_toko',
				'title' => esc_html__( 'Info Toko', 'themefood' ),
			),
			array(
				'id'    => 'katalog',
				'title' => esc_html__( 'Katalog', 'themefood' ),
			),
			array(
				'id'    => 'checkout',
				'title' => esc_html__( 'Checkout', 'themefood' ),
			),
			array(
				'id'    => 'follow_up',
				'title' => esc_html__( 'Follow Up', 'themefood' ),
			),
			array(
				'id'    => 'struk',
				'title' => esc_html__( 'Struk', 'themefood' ),
			),
			array(
				'id'    => 'sales_popup',
				'title' => esc_html__( 'Sales Popup', 'themefood' ),
			),
			array(
				'id'    => 'pwa',
				'title' => esc_html__( 'PWA', 'themefood' ),
			),
			array(
				'id'    => 'kode_footer',
				'title' => esc_html__( 'Kode Footer', 'themefood' ),
			),
			array(
				'id'    => 'admin_theme',
				'title' => esc_html__( 'Admin', 'themefood' ),
			),
			array(
				'id'    => 'form_order',
				'title' => esc_html__( 'Form Order', 'themefood' ),
			),
			array(
				'id'    => 'bantuan',
				'title' => esc_html__( 'Bantuan', 'themefood' ),
			),
		),
		'settings'        => array(
			array(
				'id'           => 'tab_info',
				'label'        => esc_html__( 'Info &amp; Alamat', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'info_toko',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'nama_toko',
				'label'        => esc_html__( 'Nama Toko', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan nama toko anda', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'info_toko',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'slogan_toko',
				'label'        => esc_html__( 'Slogan Toko', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan slogan / deskripsi singkat toko', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'info_toko',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'alamat_toko',
				'label'        => esc_html__( 'Alamat Toko', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan alamat lengkap toko beserta kontak nomor handphone', 'themefood' ),
				'std'          => '',
				'type'         => 'textarea-simple',
				'section'      => 'info_toko',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'mata_uang',
				'label'        => esc_html__( 'Mata Uang', 'themefood' ),
				'desc'         => esc_html__( 'Simbol mata uang yang digunakan di website. Default: Rp.', 'themefood' ),
				'std'          => 'Rp',
				'type'         => 'text',
				'section'      => 'info_toko',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'status_toko',
				'label'        => esc_html__( 'Status Toko', 'themefood' ),
				'desc'         => esc_html__( 'Atur status toko saat ini. Jika toko sedang tutup maka keranjang belanja tidak bisa dibuka.', 'themefood' ),
				'std'          => 'buka',
				'type'         => 'radio',
				'section'      => 'info_toko',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'buka',
						'label' => esc_html__( 'Buka', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'tutup',
						'label' => esc_html__( 'Tutup', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'pesan_toko',
				'label'        => esc_html__( 'Pesan Saat Tutup', 'themefood' ),
				'desc'         => esc_html__( 'Pesan yang ditampilkan ketika klik tombol keranjang saat toko tutup.', 'themefood' ),
				'std'          => 'Mohon maaf, toko sedang tutup. Silahkan kunjungi kembali nanti.',
				'type'         => 'text',
				'section'      => 'info_toko',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'status_toko:is(tutup)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'social_thumbnail',
				'label'        => esc_html__( 'Social Thumbnail', 'themefood' ),
				'desc'         => esc_html__( 'Upload thumbnail dengan format kotak berukuran 1200 x 630 pixels untuk gambar preview link di social media.', 'themefood' ),
				'std'          => '',
				'type'         => 'upload',
				'section'      => 'info_toko',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_logo',
				'label'        => esc_html__( 'Logo &amp; Icon', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'info_toko',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'favicon_website',
				'label'        => esc_html__( 'Icon Website', 'themefood' ),
				'desc'         => esc_html__( 'Upload icon website dengan format kotak berukuran minimal 48x48 pixels', 'themefood' ),
				'std'          => '',
				'type'         => 'upload',
				'section'      => 'info_toko',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'logo_website',
				'label'        => esc_html__( 'Logo Website', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan logo dengan format memanjang. Jika logo cenderung berbentuk kotak, <strong>KOSONGKAN</strong> kolom ini dan upload logo tersebut pada kolom "Icon Website"', 'themefood' ),
				'std'          => '',
				'type'         => 'upload',
				'section'      => 'info_toko',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_desain',
				'label'        => esc_html__( 'Desain', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'background_katalog',
				'label'        => esc_html__( 'Background Katalog', 'themefood' ),
				'desc'         => esc_html__( 'Upload background katalog untuk tampilan desktop', 'themefood' ),
				'std'          => '',
				'type'         => 'upload',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'background_header',
				'label'        => esc_html__( 'Background Header', 'themefood' ),
				'desc'         => esc_html__( 'Pilih warna background untuk header. Default: Putih', 'themefood' ),
				'std'          => '#ffffff',
				'type'         => 'colorpicker',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'teks_header',
				'label'        => esc_html__( 'Teks Header', 'themefood' ),
				'desc'         => esc_html__( 'Warna tema untuk teks pada header. Pilih <strong>Dark</strong> jika background berwarna terang & <strong>White</strong> jika background header berwarna gelap.', 'themefood' ),
				'std'          => 'dark',
				'type'         => 'radio',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'dark',
						'label' => esc_html__( 'Dark', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'white',
						'label' => esc_html__( 'White', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'button_color',
				'label'        => esc_html__( 'Button Color', 'themefood' ),
				'desc'         => esc_html__( 'Pilih warna tema untuk tombol pada halaman katalog. Default: Hijau', 'themefood' ),
				'std'          => '#03AA0E',
				'type'         => 'colorpicker',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tampilan_desktop',
				'label'        => esc_html__( 'Tampilan Desktop', 'themefood' ),
				'desc'         => esc_html__( 'Tampilan layout halaman katalog saat diakses di layar berukuran besar (laptop, komputer)', 'themefood' ),
				'std'          => 'mobile',
				'type'         => 'radio-image',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'mobile',
						'label' => esc_html__( 'Mobile View', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-desktop-mobile.jpg',
					),
					array(
						'value' => 'desktop',
						'label' => esc_html__( 'Desktop View', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-desktop-full.jpg',
					),
				),
			),
			array(
				'id'           => 'aktifkan_loader',
				'label'        => esc_html__( 'Page Loader', 'themefood' ),
				'desc'         => esc_html__( 'Aktif / Nonaktifkan fitur page loader pada awal load halaman Katalog', 'themefood' ),
				'std'          => 'on',
				'type'         => 'on-off',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'style_loader',
				'label'        => esc_html__( 'Style Page Loader', 'themefood' ),
				'desc'         => esc_html__( 'Pilih style fitur page loader pada awal load halaman Katalog.', 'themefood' ),
				'std'          => '1',
				'type'         => 'select',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'aktifkan_loader:is(on)',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => '1',
						'label' => esc_html__( 'Style 1', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '2',
						'label' => esc_html__( 'Style 2', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '3',
						'label' => esc_html__( 'Style 3', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '4',
						'label' => esc_html__( 'Style 4', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '5',
						'label' => esc_html__( 'Style 5', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '6',
						'label' => esc_html__( 'Style 6', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '7',
						'label' => esc_html__( 'Style 7', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '8',
						'label' => esc_html__( 'Style 8', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'layanan_cdn',
				'label'        => esc_html__( 'CDN', 'themefood' ),
				'desc'         => esc_html__( 'Pilih layanan CDN (Content Delivery Network) untuk images. Clear REST Cache jika melakukan perubahan.', 'themefood' ),
				'std'          => 'statically',
				'type'         => 'select',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'statically',
						'label' => esc_html__( 'Statically (Free)', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'bunny',
						'label' => esc_html__( 'BunnyCDN', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'none',
						'label' => esc_html__( 'None', 'themefood' ),
						'src'   => '',
					)
				),
			),
			array(
				'id'           => 'bunny_hostname',
				'label'        => esc_html__( 'Bunny Hostname', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan url hostname yang terdapat di Pull Zones BunnyCDN (Misal: xxx.b-cdn.net)', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'layanan_cdn:is(bunny)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_struktur',
				'label'        => esc_html__( 'Struktur', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_slider',
				'label'        => esc_html__( 'Slider', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'jumlah_foto_slider',
				'label'        => esc_html__( 'Jumlah Foto Slider', 'themefood' ),
				'desc'         => esc_html__( 'Tentukan jumlah foto slider promo yang tampil di katalog', 'themefood' ),
				'std'          => '5',
				'type'         => 'numeric-slider',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '1,10,1',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tampilan_slider',
				'label'        => esc_html__( 'Tampilan Slider', 'themefood' ),
				'desc'         => esc_html__( 'Tampilan desain slider pada halaman katalog', 'themefood' ),
				'std'          => 'partial',
				'type'         => 'radio-image',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'partial',
						'label' => esc_html__( 'Partial Width', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-slider-partial.jpg',
					),
					array(
						'value' => 'full',
						'label' => esc_html__( 'Full Width', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-slider-full.jpg',
					),
				),
			),
			array(
				'id'           => 'aktifkan_autoslide',
				'label'        => esc_html__( 'Aktifkan Auto Slide', 'themefood' ),
				'desc'         => esc_html__( 'Aktif / Nonaktifkan fitur Auto Slide pada slider halaman Katalog', 'themefood' ),
				'std'          => 'off',
				'type'         => 'on-off',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'tampilan_slider:is(full)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'interval_autoslide',
				'label'        => esc_html__( 'Interval Auto Slide', 'themefood' ),
				'desc'         => esc_html__( 'Tentukan interval waktu slider untuk auto slide', 'themefood' ),
				'std'          => '5',
				'type'         => 'numeric-slider',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '3,10,1',
				'class'        => '',
				'condition'    => 'aktifkan_autoslide:is(on),tampilan_slider:is(full)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_tombol_cta',
				'label'        => esc_html__( 'Call-To-Action', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tombol_cta',
				'label'        => esc_html__( 'Tombol CTA', 'themefood' ),
				'desc'         => esc_html__( 'Maksimal 3 tombol yang dapat ditambahkan pada halaman Katalog', 'themefood' ),
				'std'          => '',
				'type'         => 'list-item',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'settings'     => array( 
					array(
						'id'           => 'cta_icon',
						'label'        => esc_html__( 'Icon Tombol', 'themefood' ),
						'desc'         => '',
						'std'          => '',
						'type'         => 'select',
						'rows'         => '',
						'post_type'    => '',
						'taxonomy'     => '',
						'min_max_step' => '',
						'class'        => '',
						'condition'    => '',
						'operator'     => 'and',
						'choices'      => array(
							array(
								'value' => 'custom-gojek',
								'label' => esc_html__( 'Gojek', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => 'custom-grab',
								'label' => esc_html__( 'Grab', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => 'custom-tokopedia',
								'label' => esc_html__( 'Tokopedia', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => 'custom-shopee',
								'label' => esc_html__( 'Shopee', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => 'custom-bukalapak',
								'label' => esc_html__( 'Bukalapak', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => 'custom-lazada',
								'label' => esc_html__( 'Lazada', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => 'md-map',
								'label' => esc_html__( 'Maps', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => 'logo-facebook',
								'label' => esc_html__( 'Facebook', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => 'logo-instagram',
								'label' => esc_html__( 'Instagram', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => 'logo-youtube',
								'label' => esc_html__( 'YouTube', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => 'logo-whatsapp',
								'label' => esc_html__( 'WhatsApp', 'themefood' ),
								'src'   => '',
							),
						),
					),
					array(
						'id'           => 'cta_link',
						'label'        => esc_html__( 'Link Tombol', 'themefood' ),
						'desc'         => '',
						'std'          => '',
						'type'         => 'text',
						'rows'         => '',
						'post_type'    => '',
						'taxonomy'     => '',
						'min_max_step' => '',
						'class'        => '',
						'condition'    => '',
						'operator'     => 'and',
					),
					array(
						'id'           => 'cta_teks',
						'label'        => esc_html__( 'Teks Tombol', 'themefood' ),
						'desc'         => '',
						'std'          => '',
						'type'         => 'text',
						'rows'         => '',
						'post_type'    => '',
						'taxonomy'     => '',
						'min_max_step' => '',
						'class'        => '',
						'condition'    => '',
						'operator'     => 'and',
					),
				),
			),
			array(
				'id'           => 'title_tombol_chat',
				'label'        => esc_html__( 'Tombol Chat', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'teks_tombol_chat',
				'label'        => esc_html__( 'Teks Tombol Chat', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan teks untuk tombol chat. Default: Chat CS.', 'themefood' ),
				'std'          => 'Chat CS',
				'type'         => 'text',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'judul_widget_chat',
				'label'        => esc_html__( 'Judul Widget Chat', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan judul untuk header widget chat. Default: Ada pertanyaan? Chat aja...', 'themefood' ),
				'std'          => 'Ada pertanyaan?<br>Chat aja...',
				'type'         => 'text',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'subjudul_widget_chat',
				'label'        => esc_html__( 'Subjudul Widget Chat', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan subjudul untuk header widget chat. Default: Biasa menjawab dalam 5 menit.', 'themefood' ),
				'std'          => 'Biasa menjawab dalam 5 menit',
				'type'         => 'text',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_info_artikel',
				'label'        => esc_html__( 'Info Artikel', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'judul_info',
				'label'        => esc_html__( 'Judul Info', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan judul untuk kolom info. Misal: Info resto, Info promo. Default: Info Artikel.', 'themefood' ),
				'std'          => 'Info Artikel',
				'type'         => 'text',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'jumlah_info',
				'label'        => esc_html__( 'Jumlah Info', 'themefood' ),
				'desc'         => esc_html__( 'Tentukan jumlah info yang tampil pada awal load katalog', 'themefood' ),
				'std'          => '3',
				'type'         => 'numeric-slider',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '2,5,1',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_kategori',
				'label'        => esc_html__( 'Kategori', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'urutan_kategori',
				'label'        => esc_html__( 'Urutan Kategori', 'themefood' ),
				'desc'         => esc_html__( 'Pilih metode pengurutan kategori dan produk pada halaman katalog.', 'themefood' ),
				'std'          => 'urut',
				'type'         => 'radio',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'urut',
						'label' => esc_html__( 'Berurutan', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'acak',
						'label' => esc_html__( 'Urutan Acak', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'tampilan_kategori',
				'label'        => esc_html__( 'Tampilan Kategori', 'themefood' ),
				'desc'         => esc_html__( 'Tampilan desain kategori produk pada halaman katalog', 'themefood' ),
				'std'          => 'default',
				'type'         => 'radio-image',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'default',
						'label' => esc_html__( 'Default', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-kat-default.jpg',
					),
					array(
						'value' => 'alternate',
						'label' => esc_html__( 'Alternatif', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-kat-alt.jpg',
					),
					array(
						'value' => 'grid',
						'label' => esc_html__( 'Grid', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-kat-grid.jpg',
					),
					array(
						'value' => 'tabbed',
						'label' => esc_html__( 'Tab', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-kat-tab.jpg',
					),
				),
			),
			array(
				'id'           => 'title_produk',
				'label'        => esc_html__( 'Produk', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'placeholder_instruksi',
				'label'        => esc_html__( 'Placeholder Instruksi', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan teks untuk placeholder pada kolom Instruksi Pemesanan. Default: "Misal: Jangan pedas ya!"', 'themefood' ),
				'std'          => 'Misal: Jangan pedas ya!',
				'type'         => 'text',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'jumlah_produk',
				'label'        => esc_html__( 'Jumlah Produk', 'themefood' ),
				'desc'         => esc_html__( 'Tentukan jumlah produk per kategori yang tampil pada awal load', 'themefood' ),
				'std'          => '5',
				'type'         => 'numeric-slider',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '3,10,1',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tampilan_produk',
				'label'        => esc_html__( 'Tampilan Produk (Mobile)', 'themefood' ),
				'desc'         => esc_html__( 'Tampilan desain produk pada halaman katalog mode mobile', 'themefood' ),
				'std'          => 'default',
				'type'         => 'radio-image',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'default',
						'label' => esc_html__( 'Cards', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-cards.jpg',
					),
					array(
						'value' => 'compact',
						'label' => esc_html__( 'Compact', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-compact.jpg',
					),
					array(
						'value' => 'grid2',
						'label' => esc_html__( 'Two Grid', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-grid.jpg',
					),
					array(
						'value' => 'grid1',
						'label' => esc_html__( 'One Grid', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-feed.jpg',
					),
				),
			),
			array(
				'id'           => 'tampilan_produk_choice',
				'label'        => esc_html__( 'Tampilan Produk (Desktop)', 'themefood' ),
				'desc'         => esc_html__( 'Pilih metode pengurutan kategori dan produk pada halaman katalog.', 'themefood' ),
				'std'          => 'sama',
				'type'         => 'select',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'sama',
						'label' => esc_html__( 'Sama Dengan Mobile', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'beda',
						'label' => esc_html__( 'Berbeda', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'tampilan_produk_desktop',
				'label'        => esc_html__( 'Pilih Tampilan Produk (Desktop)', 'themefood' ),
				'desc'         => esc_html__( 'Tampilan desain produk pada halaman katalog mode desktop', 'themefood' ),
				'std'          => 'default',
				'type'         => 'radio-image',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'tampilan_produk_choice:is(beda)',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'default',
						'label' => esc_html__( 'Cards', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-cards.jpg',
					),
					array(
						'value' => 'compact',
						'label' => esc_html__( 'Compact', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-compact.jpg',
					),
					array(
						'value' => 'grid2',
						'label' => esc_html__( 'Two Grid', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-grid.jpg',
					),
					array(
						'value' => 'grid1',
						'label' => esc_html__( 'One Grid', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-feed.jpg',
					),
				),
			),
			array(
				'id'           => 'title_keranjang',
				'label'        => esc_html__( 'Keranjang Belanja', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tampilan_keranjang',
				'label'        => esc_html__( 'Tampilan Keranjang', 'themefood' ),
				'desc'         => esc_html__( 'Tampilan desain tombol keranjang belanja pada halaman katalog', 'themefood' ),
				'std'          => 'default',
				'type'         => 'radio-image',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'default',
						'label' => esc_html__( 'Default', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-cart-default.jpg',
					),
					array(
						'value' => 'floating',
						'label' => esc_html__( 'Floating', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-cart-floating.jpg',
					),
					array(
						'value' => 'full',
						'label' => esc_html__( 'Full Width', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-cart-full.jpg',
					),
					array(
						'value' => 'mini',
						'label' => esc_html__( 'Mini Button', 'themefood' ),
						'src'   => get_template_directory_uri() . '/img/design-cart-mini.jpg',
					),
				),
			),
			array(
				'id'           => 'icon_kat',
				'label'        => esc_html__( 'Icon Kategori', 'themefood' ),
				'desc'         => esc_html__( 'Pilih icon kategori yang sesuai dengan tipe produk.', 'themefood' ),
				'std'          => 'restaurant',
				'type'         => 'select',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'archive',
						'label' => esc_html__( 'Icon Archive', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'cafe',
						'label' => esc_html__( 'Icon Cafe', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'cube',
						'label' => esc_html__( 'Icon Cube', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'gift',
						'label' => esc_html__( 'Icon Gift', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'ice-cream',
						'label' => esc_html__( 'Icon Ice Cream', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'laptop',
						'label' => esc_html__( 'Icon Laptop', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'leaf',
						'label' => esc_html__( 'Icon Leaf', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'list',
						'label' => esc_html__( 'Icon List', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'medkit',
						'label' => esc_html__( 'Icon Medical', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'paw',
						'label' => esc_html__( 'Icon Paw', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'pizza',
						'label' => esc_html__( 'Icon Pizza', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'restaurant',
						'label' => esc_html__( 'Icon Restaurant', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'rose',
						'label' => esc_html__( 'Icon Rose', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'star',
						'label' => esc_html__( 'Icon Star', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'school',
						'label' => esc_html__( 'Icon School', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'shirt',
						'label' => esc_html__( 'Icon Shirt', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'water',
						'label' => esc_html__( 'Icon Water', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'title_copyright',
				'label'        => esc_html__( 'Copyright', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'teks_copyright',
				'label'        => esc_html__( 'Teks Copyright', 'themefood' ),
				'desc'         => esc_html__( 'Copyright text pada bagian footer halaman Katalog', 'themefood' ),
				'std'          => 'Copyright © 2021. <a href="https://themefood.id" target="_blank">ThemeFood.id</a>',
				'type'         => 'text',
				'section'      => 'katalog',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_keranjang_belanja',
				'label'        => esc_html__( 'Keranjang', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'format_order',
				'label'        => esc_html__( 'Format Order', 'themefood' ),
				'desc'         => '',
				'std'          => 'Halo kak admin! 🖐

*Saya mau pesan produk ini:*
[produk]

*Berikut data profil saya:*
👤 *Nama:* [nama]
📧 *Email:* [email]
📱 *No WA:* [nowa]

*Alamat:*
🏠 [alamat] [lokasi]

*Total orderan saya:*
🛵 *Ongkir:* [ongkir]
🏷 *Diskon:* [diskon]
💰 *Total:* [total]

*Pembayaran via:*
[pembayaran]

[instruksi]

Terima kasih, *mohon dibalas ya* 🙏',
				'type'         => 'textarea-simple',
				'section'      => 'checkout',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tampilkan_berat',
				'label'        => esc_html__( 'Tampilkan Berat', 'themefood' ),
				'desc'         => esc_html__( 'Tampilkan berat produk di keranjang belanja', 'themefood' ),
				'std'          => 'yes',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'yes',
						'label' => esc_html__( 'Ya', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'no',
						'label' => esc_html__( 'Tidak', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'tampilkan_email',
				'label'        => esc_html__( 'Tampilkan Kolom Email', 'themefood' ),
				'desc'         => esc_html__( 'Tampilkan kolom isian email di keranjang belanja', 'themefood' ),
				'std'          => 'yes',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'yes',
						'label' => esc_html__( 'Ya', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'no',
						'label' => esc_html__( 'Tidak', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'metode_checkout',
				'label'        => esc_html__( 'Metode Checkout', 'themefood' ),
				'desc'         => esc_html__( 'Pilih metode checkout yang ingin ditampilkan, delivery, dine-in atau keduanya.', 'themefood' ),
				'std'          => 'both',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'both',
						'label' => esc_html__( 'Delivery &amp; Dine-In', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'delivery',
						'label' => esc_html__( 'Delivery', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'dine',
						'label' => esc_html__( 'Dine-In', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'metode_pengiriman',
				'label'        => esc_html__( 'Metode Pengiriman', 'themefood' ),
				'desc'         => esc_html__( 'Pilih metode pengiriman yang ingin diterapkan<br><strong>Kurir</strong>: Perhitungan ongkos kirim dengan JNE, Tiki, Pos, dan sejenisnya<br><strong>Ojek Online</strong>: Perhitungan ongkos kirim berdasarkan jarak lokasi<br><strong>Tarif Flat</strong>: Ongkos kirim dengan harga flat<br><strong>None</strong>: Nonaktifkan perhitungan ongkos kirim', 'themefood' ),
				'std'          => 'none',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'kurir',
						'label' => esc_html__( 'Kurir', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'ojol',
						'label' => esc_html__( 'Ojek Online', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'flat',
						'label' => esc_html__( 'Tarif Flat', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'none',
						'label' => esc_html__( 'None', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'aktifkan_switcher',
				'label'        => esc_html__( 'Aktifkan Shipping Switcher', 'themefood' ),
				'desc'         => esc_html__( 'Aktif / Nonaktifkan fitur Shipping Switcher untuk berganti metode pengiriman (Kurir & Ojek Online) di halaman keranjang.', 'themefood' ),
				'std'          => 'off',
				'type'         => 'on-off',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'metode_pengiriman:is(kurir),metode_pengiriman:is(ojol)',
				'operator'     => 'or',
			),
			array(
				'id'           => 'metode_pembayaran',
				'label'        => esc_html__( 'Metode Pembayaran', 'themefood' ),
				'desc'         => esc_html__( 'Pilih metode pembayaran yang ingin diterapkan. Anda bisa memilih lebih dari satu metode. Atur masing-masing metode pada tab <strong>Info Pembayaran</strong>.', 'themefood' ),
				'std'          => '',
				'type'         => 'checkbox',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'transfer-bank',
						'label' => esc_html__( 'Transfer Bank', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'cod',
						'label' => esc_html__( 'COD', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'bayar-di-kasir',
						'label' => esc_html__( 'Bayar di Kasir', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'durianpay',
						'label' => esc_html__( 'DurianPay', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'minimum_order',
				'label'        => esc_html__( 'Minimum Order (' . $currency_sym . ')', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan nominal minimum subtotal belanja jika ingin mengaktifkan fitur minimum order agar dapat checkout. <strong>KOSONGKAN</strong> jika ingin menonaktifkannya.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_kurir',
				'label'        => esc_html__( 'Kurir', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'deskripsi_kurir',
				'label'        => esc_html__( 'Deskripsi Kurir', 'themefood' ),
				'desc'         => esc_html__( 'Metode pengiriman dari beragam kurir yang ada di Indonesia. Menggunakan API RajaOngkir PRO untuk mendapatkan tarif hingga level kecamatan. Anda dapat mengaktifkan beberapa kurir sekaligus dengan centang pada pilihan di bawah ini.', 'themefood' ),
				'std'          => '',
				'type'         => 'textblock',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'api_rajaongkir',
				'label'        => esc_html__( 'API RajaOngkir', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan API RajaOngkir <strong>VERSI PRO</strong> milik anda sendiri agar lebih stabil. Jika dikosongkan maka akan menggunakan API bersama yang bisa overload sewaktu-waktu. Klik <a href="https://rajaongkir.com/akun/masuk?lalu=akun/profil" target="_blank">disini</a> untuk mendapatkannya.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'kecamatan_asal',
				'label'        => esc_html__( 'Kecamatan Asal', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan kecamatan asal pengiriman. Ketik dan pilih kecamatan dari dropdown yang muncul.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'kecamatan_id',
				'label'        => esc_html__( 'Kecamatan ID', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'pilihan_kurir',
				'label'        => esc_html__( 'Pilihan Kurir', 'themefood' ),
				'desc'         => esc_html__( 'Pilihan kurir yang ingin ditampilkan. Rekomendasi maksimum 3 kurir yang ditampilkan bersamaan dalam satu waktu.', 'themefood' ),
				'std'          => '',
				'type'         => 'checkbox',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'jne',
						'label' => esc_html__( 'JNE', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'pos',
						'label' => esc_html__( 'POS', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'tiki',
						'label' => esc_html__( 'TIKI', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'sicepat',
						'label' => esc_html__( 'SiCepat Express', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'jnt',
						'label' => esc_html__( 'JNT', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'ninja',
						'label' => esc_html__( 'Ninja Xpress', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'jet',
						'label' => esc_html__( 'JET Express', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'lion',
						'label' => esc_html__( 'Lion Parcel', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'ide',
						'label' => esc_html__( 'ID Express', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'sap',
						'label' => esc_html__( 'SAP Express', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'wahana',
						'label' => esc_html__( 'Wahana', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'pahala',
						'label' => esc_html__( 'Pahala', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'pandu',
						'label' => esc_html__( 'Pandu Logistics', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'rex',
						'label' => esc_html__( 'Royal Express', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'ncs',
						'label' => esc_html__( 'NCS', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'rpx',
						'label' => esc_html__( 'RPX', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'first',
						'label' => esc_html__( 'First Logistics', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'dse',
						'label' => esc_html__( '21 Express', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'star',
						'label' => esc_html__( 'Star Cargo', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'idl',
						'label' => esc_html__( 'IDL Cargo', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'slis',
						'label' => esc_html__( 'Solusi Express', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'tab_ojol',
				'label'        => esc_html__( 'Ojek Online', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'deskripsi_ojol',
				'label'        => esc_html__( 'Deskripsi Ojol', 'themefood' ),
				'desc'         => esc_html__( 'Metode pengiriman Ojek Online tidak terintegrasi secara langsung dengan sistem ojek online yang ada seperti Gojek, Grab, dan lainnya. Dengan metode ini, anda dapat membuat perhitungan ongkos kirim berdasarkan jarak kilometer baik dengan biaya per kilometer dari ojek online yang ada atau biaya yang anda atur sendiri jika menggunakan kurir toko.', 'themefood' ),
				'std'          => '',
				'type'         => 'textblock',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'nama_kurir',
				'label'        => esc_html__( 'Label Kurir', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan label kurir, misal: GoSend, Ojek Online, Kurir Toko, dsb.', 'themefood' ),
				'std'          => 'Ojek Online',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'api_open_route',
				'label'        => esc_html__( 'API OpenRoute', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan API Key OpenRouteService untuk menampilkan maps dan perhitungan rute jarak. Anda dapat memasukkan lebih dari satu key jika ingin meningkatkan limitasi default 2000 call / key / bulan. Klik <a href="https://openrouteservice.org/dev/#/home" target="_blank">disini</a> untuk mendapatkan key.', 'themefood' ),
				'std'          => '',
				'type'         => 'list-item',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'settings'     => array( 
					array(
						'id'           => 'token_key',
						'label'        => esc_html__( 'Token Key', 'themefood' ),
						'desc'         => '',
						'std'          => '',
						'type'         => 'text',
						'rows'         => '',
						'post_type'    => '',
						'taxonomy'     => '',
						'min_max_step' => '',
						'class'        => '',
						'condition'    => '',
						'operator'     => 'and',
					),
				),
			),			
			array(
				'id'           => 'lokasi_toko',
				'label'        => esc_html__( 'Lokasi Toko', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan lokasi toko dalam format koordinat "Latitude,Longitude". Misal: -6.1753871,106.8249641. Anda dapat menambahkan lebih dari satu lokasi untuk mengaktifkan fitur Multi Location.', 'themefood' ),
				'std'          => '',
				'type'         => 'list-item',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'settings'     => array( 
					array(
						'id'           => 'nama_lokasi',
						'label'        => esc_html__( 'Nama Lokasi', 'themefood' ),
						'desc'         => '',
						'std'          => '',
						'type'         => 'text',
						'rows'         => '',
						'post_type'    => '',
						'taxonomy'     => '',
						'min_max_step' => '',
						'class'        => '',
						'condition'    => '',
						'operator'     => 'and',
					),
					array(
						'id'           => 'koordinat_lokasi',
						'label'        => esc_html__( 'Koordinat Lokasi', 'themefood' ),
						'desc'         => '',
						'std'          => '',
						'type'         => 'text',
						'rows'         => '',
						'post_type'    => '',
						'taxonomy'     => '',
						'min_max_step' => '',
						'class'        => '',
						'condition'    => '',
						'operator'     => 'and',
					),
				),
			),
			array(
				'id'           => 'max_jangkauan',
				'label'        => esc_html__( 'Max Jangkauan', 'themefood' ),
				'desc'         => esc_html__( 'Maksimum jangkauan yang bisa ditempuh dari toko dalam satuan kilometer.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'metode_tarif',
				'label'        => esc_html__( 'Metode Perhitungan', 'themefood' ),
				'desc'         => esc_html__( 'Pilih metode perhitungan tarif yang sesuai kebutuhan.', 'themefood' ),
				'std'          => 'perkilo',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'perkilo',
						'label' => esc_html__( 'Tarif per KM', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'flat',
						'label' => esc_html__( 'Tarif Flat', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'tarif_per_km',
				'label'        => esc_html__( 'Tarif per KM (' . $currency_sym . ')', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan tarif ongkos kirim per KM (kilometer). Cukup angka, tanpa simbol mata uang atau titik.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'metode_tarif:is(perkilo)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'ojol_flat',
				'label'        => esc_html__( 'Tarif Flat Ojol (' . $currency_sym . ')', 'themefood' ),
				'desc'         => esc_html__( 'Isi kolom ini jika anda ingin mengaktifkan tarif flat baik jauh maupun dekat selama dalam jangkauan pengantaran.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'metode_tarif:is(flat)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'aktifkan_tarifdasar',
				'label'        => esc_html__( 'Aktifkan Tarif Dasar', 'themefood' ),
				'desc'         => esc_html__( 'Aktif / Nonaktifkan perhitungan tarif dasar flat dalam jangkauan sekian KM.', 'themefood' ),
				'std'          => 'off',
				'type'         => 'on-off',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'metode_tarif:is(perkilo)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tarif_dasar',
				'label'        => esc_html__( 'Tarif Dasar Flat (' . $currency_sym . ')', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan tarif dasar dengan perhitungan flat hingga jangkauan __ KM. Isi dengan angka 0 jika anda ingin menerapkan free ongkir untuk __ KM pertama. Jangkauan bisa diatur pada kolom selanjutnya.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'aktifkan_tarifdasar:is(on)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'jangkauan_dasar',
				'label'        => esc_html__( 'Jangkauan Tarif Dasar', 'themefood' ),
				'desc'         => esc_html__( 'Maksimum jangkauan untuk penerapan perhitungan tarif dasar dalam satuan kilometer.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'aktifkan_tarifdasar:is(on)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'aktifkan_timeslot',
				'label'        => esc_html__( 'Delivery Date & Time', 'themefood' ),
				'desc'         => esc_html__( 'Aktif / Nonaktifkan fitur delivery date & time.', 'themefood' ),
				'std'          => 'off',
				'type'         => 'on-off',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'label_timeslot',
				'label'        => esc_html__( 'Label Delivery Date & Time', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan label delivery date & time jika ingin mengubah namanya. Default: Waktu Antar', 'themefood' ),
				'std'          => 'Waktu Antar',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'aktifkan_timeslot:is(on)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'mode_timeslot',
				'label'        => esc_html__( 'Mode Pemilihan Waktu', 'themefood' ),
				'desc'         => esc_html__( 'Mode pemilihan waktu delivery yang ingin ditampilkan.<br><strong>Time Slot</strong>: Menampilkan slot pilihan waktu delivery berdasarkan hari dan rentang jam.<br><strong>Kalender Tanggal</strong>: Menampilkan pilihan tanggal delivery dalam bentuk kalender<br><strong>Kalender Tanggal & Jam</strong>: Menampilkan kalender tanggal yang disertai dengan jam antar.', 'themefood' ),
				'std'          => 'date',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'aktifkan_timeslot:is(on)',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'timeslot',
						'label' => esc_html__( 'Time Slot', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'date',
						'label' => esc_html__( 'Kalender Tanggal', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'datetime',
						'label' => esc_html__( 'Kalender Tanggal & Jam', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'jam_timeslot',
				'label'        => esc_html__( 'Slot Waktu', 'themefood' ),
				'desc'         => esc_html__( 'Buat slot waktu untuk ditampilkan di dropdown pilihan delivery time slot. Misal, slot 10.00 - 12.00, maka isi kolom "Mulai"-nya 10.00 & kolom "Hingga"-nya 12.00.', 'themefood' ),
				'std'          => '',
				'type'         => 'list-item',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'mode_timeslot:is(timeslot),aktifkan_timeslot:is(on)',
				'operator'     => 'and',
				'settings'     => array( 
					array(
						'id'           => 'slot_mulai',
						'label'        => esc_html__( 'Mulai', 'themefood' ),
						'desc'         => '',
						'std'          => '',
						'type'         => 'select',
						'rows'         => '',
						'post_type'    => '',
						'taxonomy'     => '',
						'min_max_step' => '',
						'class'        => '',
						'condition'    => '',
						'operator'     => 'and',
						'choices'      => array(
							array(
								'value' => '00:00',
								'label' => esc_html__( '00:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '00:30',
								'label' => esc_html__( '00:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '01:00',
								'label' => esc_html__( '01:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '01:30',
								'label' => esc_html__( '01:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '02:00',
								'label' => esc_html__( '02:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '02:30',
								'label' => esc_html__( '02:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '03:00',
								'label' => esc_html__( '03:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '03:30',
								'label' => esc_html__( '03:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '04:00',
								'label' => esc_html__( '04:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '04:30',
								'label' => esc_html__( '04:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '05:00',
								'label' => esc_html__( '05:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '05:30',
								'label' => esc_html__( '05:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '06:00',
								'label' => esc_html__( '06:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '06:30',
								'label' => esc_html__( '06:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '07:00',
								'label' => esc_html__( '07:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '07:30',
								'label' => esc_html__( '07:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '08:00',
								'label' => esc_html__( '08:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '08:30',
								'label' => esc_html__( '08:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '09:00',
								'label' => esc_html__( '09:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '09:30',
								'label' => esc_html__( '09:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '10:00',
								'label' => esc_html__( '10:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '10:30',
								'label' => esc_html__( '10:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '11:00',
								'label' => esc_html__( '11:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '11:30',
								'label' => esc_html__( '11:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '12:00',
								'label' => esc_html__( '12:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '12:30',
								'label' => esc_html__( '12:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '13:00',
								'label' => esc_html__( '13:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '13:30',
								'label' => esc_html__( '13:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '14:00',
								'label' => esc_html__( '14:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '14:30',
								'label' => esc_html__( '14:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '15:00',
								'label' => esc_html__( '15:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '15:30',
								'label' => esc_html__( '15:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '16:00',
								'label' => esc_html__( '16:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '16:30',
								'label' => esc_html__( '16:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '17:00',
								'label' => esc_html__( '17:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '17:30',
								'label' => esc_html__( '17:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '18:00',
								'label' => esc_html__( '18:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '18:30',
								'label' => esc_html__( '18:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '19:00',
								'label' => esc_html__( '19:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '19:30',
								'label' => esc_html__( '19:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '20:00',
								'label' => esc_html__( '20:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '20:30',
								'label' => esc_html__( '20:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '21:00',
								'label' => esc_html__( '21:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '21:30',
								'label' => esc_html__( '21:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '22:00',
								'label' => esc_html__( '22:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '22:30',
								'label' => esc_html__( '22:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '23:00',
								'label' => esc_html__( '23:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '23:30',
								'label' => esc_html__( '23:30', 'themefood' ),
								'src'   => '',
							),
						),
					),
					array(
						'id'           => 'slot_hingga',
						'label'        => esc_html__( 'Hingga', 'themefood' ),
						'desc'         => '',
						'std'          => '',
						'type'         => 'select',
						'rows'         => '',
						'post_type'    => '',
						'taxonomy'     => '',
						'min_max_step' => '',
						'class'        => '',
						'condition'    => '',
						'operator'     => 'and',
						'choices'      => array(
							array(
								'value' => '00:00',
								'label' => esc_html__( '00:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '00:30',
								'label' => esc_html__( '00:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '01:00',
								'label' => esc_html__( '01:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '01:30',
								'label' => esc_html__( '01:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '02:00',
								'label' => esc_html__( '02:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '02:30',
								'label' => esc_html__( '02:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '03:00',
								'label' => esc_html__( '03:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '03:30',
								'label' => esc_html__( '03:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '04:00',
								'label' => esc_html__( '04:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '04:30',
								'label' => esc_html__( '04:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '05:00',
								'label' => esc_html__( '05:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '05:30',
								'label' => esc_html__( '05:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '06:00',
								'label' => esc_html__( '06:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '06:30',
								'label' => esc_html__( '06:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '07:00',
								'label' => esc_html__( '07:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '07:30',
								'label' => esc_html__( '07:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '08:00',
								'label' => esc_html__( '08:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '08:30',
								'label' => esc_html__( '08:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '09:00',
								'label' => esc_html__( '09:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '09:30',
								'label' => esc_html__( '09:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '10:00',
								'label' => esc_html__( '10:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '10:30',
								'label' => esc_html__( '10:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '11:00',
								'label' => esc_html__( '11:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '11:30',
								'label' => esc_html__( '11:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '12:00',
								'label' => esc_html__( '12:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '12:30',
								'label' => esc_html__( '12:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '13:00',
								'label' => esc_html__( '13:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '13:30',
								'label' => esc_html__( '13:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '14:00',
								'label' => esc_html__( '14:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '14:30',
								'label' => esc_html__( '14:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '15:00',
								'label' => esc_html__( '15:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '15:30',
								'label' => esc_html__( '15:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '16:00',
								'label' => esc_html__( '16:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '16:30',
								'label' => esc_html__( '16:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '17:00',
								'label' => esc_html__( '17:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '17:30',
								'label' => esc_html__( '17:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '18:00',
								'label' => esc_html__( '18:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '18:30',
								'label' => esc_html__( '18:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '19:00',
								'label' => esc_html__( '19:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '19:30',
								'label' => esc_html__( '19:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '20:00',
								'label' => esc_html__( '20:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '20:30',
								'label' => esc_html__( '20:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '21:00',
								'label' => esc_html__( '21:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '21:30',
								'label' => esc_html__( '21:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '22:00',
								'label' => esc_html__( '22:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '22:30',
								'label' => esc_html__( '22:30', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '23:00',
								'label' => esc_html__( '23:00', 'themefood' ),
								'src'   => '',
							),
							array(
								'value' => '23:30',
								'label' => esc_html__( '23:30', 'themefood' ),
								'src'   => '',
							),
						),
					),
				),
			),
			array(
				'id'           => 'hari_timeslot',
				'label'        => esc_html__( 'Slot Hari', 'themefood' ),
				'desc'         => esc_html__( 'Pilih hari operasional untuk waktu pengantaran (delivery time). Jika customer melakukan pemesanan diluar slot waktu yang tersedia, maka akan menampilkan pilihan slot waktu baru di hari berikutnya.', 'themefood' ),
				'std'          => '',
				'type'         => 'checkbox',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'mode_timeslot:is(timeslot),aktifkan_timeslot:is(on)',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => '1',
						'label' => esc_html__( 'Senin', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '2',
						'label' => esc_html__( 'Selasa', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '3',
						'label' => esc_html__( 'Rabu', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '4',
						'label' => esc_html__( 'Kamis', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '5',
						'label' => esc_html__( 'Jumat', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '6',
						'label' => esc_html__( 'Sabtu', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '7',
						'label' => esc_html__( 'Minggu', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'timeslot_weekend',
				'label'        => esc_html__( 'Status Weekend', 'themefood' ),
				'desc'         => esc_html__( 'Pilih status weekend. Jika libur maka hari Sabtu & Minggu tidak dapat dipilih.', 'themefood' ),
				'std'          => 'on',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'mode_timeslot:not(timeslot),aktifkan_timeslot:is(on)',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'on',
						'label' => esc_html__( 'Masuk', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'off',
						'label' => esc_html__( 'Libur', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'timeslot_rentangjam',
				'label'        => esc_html__( 'Rentang Jam', 'themefood' ),
				'desc'         => esc_html__( 'Atur rentang pilihan jam yang dapat dipilih.', 'themefood' ),
				'std'          => 'all',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'mode_timeslot:is(datetime),aktifkan_timeslot:is(on)',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'all',
						'label' => esc_html__( '24 Jam', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'custom',
						'label' => esc_html__( 'Custom', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'timeslot_stepmenit',
				'label'        => esc_html__( 'Kelipatan Menit', 'themefood' ),
				'desc'         => esc_html__( 'Atur kelipatan menit dalam satu jam. Default: 30.', 'themefood' ),
				'std'          => '30',
				'type'         => 'numeric-slider',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '15,60,15',
				'class'        => '',
				'condition'    => 'mode_timeslot:is(datetime),aktifkan_timeslot:is(on)',
				'operator'     => 'and',
			),		
			array(
				'id'           => 'timeslot_mulaijam',
				'label'        => esc_html__( 'Mulai Jam', 'themefood' ),
				'desc'         => esc_html__( 'Atur rentang mulai jam yang dapat dipilih.', 'themefood' ),
				'std'          => '00:00',
				'type'         => 'select',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'timeslot_rentangjam:is(custom),mode_timeslot:is(datetime),aktifkan_timeslot:is(on)',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => '0',
						'label' => esc_html__( 'Sekarang', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '00:00',
						'label' => esc_html__( '00:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '01:00',
						'label' => esc_html__( '01:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '02:00',
						'label' => esc_html__( '02:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '03:00',
						'label' => esc_html__( '03:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '04:00',
						'label' => esc_html__( '04:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '05:00',
						'label' => esc_html__( '05:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '06:00',
						'label' => esc_html__( '06:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '07:00',
						'label' => esc_html__( '07:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '08:00',
						'label' => esc_html__( '08:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '09:00',
						'label' => esc_html__( '09:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '10:00',
						'label' => esc_html__( '10:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '11:00',
						'label' => esc_html__( '11:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '12:00',
						'label' => esc_html__( '12:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '13:00',
						'label' => esc_html__( '13:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '14:00',
						'label' => esc_html__( '14:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '15:00',
						'label' => esc_html__( '15:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '16:00',
						'label' => esc_html__( '16:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '17:00',
						'label' => esc_html__( '17:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '18:00',
						'label' => esc_html__( '18:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '19:00',
						'label' => esc_html__( '19:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '20:00',
						'label' => esc_html__( '20:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '21:00',
						'label' => esc_html__( '21:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '22:00',
						'label' => esc_html__( '22:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '23:00',
						'label' => esc_html__( '23:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '23:59',
						'label' => esc_html__( '24:00', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'timeslot_hinggajam',
				'label'        => esc_html__( 'Hingga Jam', 'themefood' ),
				'desc'         => esc_html__( 'Atur rentang hingga jam yang dapat dipilih.', 'themefood' ),
				'std'          => '23:59',
				'type'         => 'select',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'timeslot_rentangjam:is(custom),mode_timeslot:is(datetime),aktifkan_timeslot:is(on)',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => '0',
						'label' => esc_html__( 'Sekarang', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '00:00',
						'label' => esc_html__( '00:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '01:00',
						'label' => esc_html__( '01:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '02:00',
						'label' => esc_html__( '02:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '03:00',
						'label' => esc_html__( '03:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '04:00',
						'label' => esc_html__( '04:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '05:00',
						'label' => esc_html__( '05:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '06:00',
						'label' => esc_html__( '06:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '07:00',
						'label' => esc_html__( '07:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '08:00',
						'label' => esc_html__( '08:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '09:00',
						'label' => esc_html__( '09:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '10:00',
						'label' => esc_html__( '10:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '11:00',
						'label' => esc_html__( '11:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '12:00',
						'label' => esc_html__( '12:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '13:00',
						'label' => esc_html__( '13:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '14:00',
						'label' => esc_html__( '14:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '15:00',
						'label' => esc_html__( '15:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '16:00',
						'label' => esc_html__( '16:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '17:00',
						'label' => esc_html__( '17:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '18:00',
						'label' => esc_html__( '18:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '19:00',
						'label' => esc_html__( '19:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '20:00',
						'label' => esc_html__( '20:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '21:00',
						'label' => esc_html__( '21:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '22:00',
						'label' => esc_html__( '22:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '23:00',
						'label' => esc_html__( '23:00', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '23:59',
						'label' => esc_html__( '24:00', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'tab_flat',
				'label'        => esc_html__( 'Flat', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'deskripsi_flat',
				'label'        => esc_html__( 'Deskripsi Flat', 'themefood' ),
				'desc'         => esc_html__( 'Metode pengiriman dengan perhitungan ongkos kirim flat ke semua tujuan alamat. Gunakan metode ini hanya jika sesuai dengan kebutuhan dan kondisi toko anda.', 'themefood' ),
				'std'          => '',
				'type'         => 'textblock',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tarif_flat',
				'label'        => esc_html__( 'Tarif Flat (' . $currency_sym . ')', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan tarif ongkos kirim dengan biaya flat ke semua tujuan', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_dinein',
				'label'        => esc_html__( 'Dine In', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),			
			array(
				'id'           => 'jumlah_meja',
				'label'        => esc_html__( 'Jumlah Meja', 'themefood' ),
				'desc'         => esc_html__( 'Atur jumlah meja yang tersedia jika mengaktifkan pemesanan untuk makan di tempat / Dine-In', 'themefood' ),
				'std'          => '',
				'type'         => 'numeric-slider',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '1,30,1',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),		
			array(
				'id'           => 'tab_moota',
				'label'        => esc_html__( 'Moota & Kode Unik', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),			
			array(
				'id'           => 'deskripsi_moota',
				'label'        => esc_html__( 'Deskripsi Moota', 'themefood' ),
				'desc'         => esc_html__( 'Verifikasi pembayaran otomatis menggunakan layanan Moota. Masukkan URL <code>'.get_bloginfo('url').'/?gateway=moota</code> ke dalam pengaturan <a href="https://app.moota.co/integrations/webhook" target="_blank">webhook Moota</a>.', 'themefood' ),
				'std'          => '',
				'type'         => 'textblock',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'moota_secret',
				'label'        => esc_html__( 'Secret Token', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan secret token yang didapat saat proses tambah webhook di halaman <a href="https://app.moota.co/integrations/webhook" target="_blank">webhook Moota</a>', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'moota_status',
				'label'        => esc_html__( 'Status Berhasil', 'themefood' ),
				'desc'         => esc_html__( 'Ubah status orderan yang berhasil setelah menemukan orderan yang telah dibayar.', 'themefood' ),
				'std'          => 'diproses',
				'type'         => 'select',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'diproses',
						'label' => esc_html__( 'Diproses', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'diantar',
						'label' => esc_html__( 'Diantar', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'selesai',
						'label' => esc_html__( 'Selesai', 'themefood' ),
						'src'   => '',
					)
				),
			),
			array(
				'id'           => 'moota_cekhari',
				'label'        => esc_html__( 'Batas Pengecekan (hari)', 'themefood' ),
				'desc'         => esc_html__( 'Pengecekan orderan berdasarkan x hari ke belakang. (Default: 7 hari ke belakang)', 'themefood' ),
				'std'          => '7',
				'type'         => 'numeric-slider',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '1,10,1',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_kodeunik',
				'label'        => esc_html__( 'Kode Unik', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tampilkan_kodeunik',
				'label'        => esc_html__( 'Tampilkan Kode Unik', 'themefood' ),
				'desc'         => esc_html__( 'Tampilkan kode unik pada keranjang belanja', 'themefood' ),
				'std'          => 'no',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'yes',
						'label' => esc_html__( 'Ya', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'no',
						'label' => esc_html__( 'Tidak', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'nama_kodeunik',
				'label'        => esc_html__( 'Label Kode Unik', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan label untuk kolom kode unik, misal: Kode Unik, Angka Unik, dsb.', 'themefood' ),
				'std'          => 'Kode Unik',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'tampilkan_kodeunik:is(yes)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'digit_kodeunik',
				'label'        => esc_html__( 'Digit Kode Unik', 'themefood' ),
				'desc'         => esc_html__( 'Pilih jumlah digit kode unik', 'themefood' ),
				'std'          => '2',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'tampilkan_kodeunik:is(yes)',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => '2',
						'label' => esc_html__( '2 Digit', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => '3',
						'label' => esc_html__( '3 Digit', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'metode_kodeunik',
				'label'        => esc_html__( 'Metode Kode Unik', 'themefood' ),
				'desc'         => esc_html__( 'Pilih metode penambahan atau pengurangan total jika kode unik diaktifkan', 'themefood' ),
				'std'          => 'plus',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'tampilkan_kodeunik:is(yes)',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'plus',
						'label' => esc_html__( 'Penambahan', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'minus',
						'label' => esc_html__( 'Pengurangan', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'tab_promo',
				'label'        => esc_html__( 'Promo', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_diskonongkir',
				'label'        => esc_html__( 'Diskon Ongkir', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'diskon_ongkir',
				'label'        => esc_html__( 'Metode Diskon', 'themefood' ),
				'desc'         => esc_html__( 'Pilih metode promo diskon ongkir berdasarkan minimum pembelanjaan', 'themefood' ),
				'std'          => 'off',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'off',
						'label' => esc_html__( 'Off', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'free',
						'label' => esc_html__( 'Diskon 100% (Free Ongkir)', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'nominal',
						'label' => esc_html__( 'Diskon Nominal', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'minimum_belanja',
				'label'        => esc_html__( 'Minimum Belanja (' . $currency_sym . ')', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan nominal minimum pembelanjaan yang diperlukan oleh customer agar mendapatkan promo diskon ongkir', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'diskon_ongkir:is(free),diskon_ongkir:is(nominal)',
				'operator'     => 'or',
			),
			array(
				'id'           => 'nominal_diskon',
				'label'        => esc_html__( 'Nominal Diskon (' . $currency_sym . ')', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan nominal potongan diskon ongkir', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'diskon_ongkir:is(nominal)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_fee',
				'label'        => esc_html__( 'Fee', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_fee',
				'label'        => esc_html__( 'Additional Fee', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'additional_fee',
				'label'        => esc_html__( 'Biaya Tambahan', 'themefood' ),
				'desc'         => esc_html__( 'Pilih metode biaya tambahan yang dikenakan pada keranjang belanja. Misal biaya tambahan untuk packing, biaya tambahan COD, dsb.', 'themefood' ),
				'std'          => 'off',
				'type'         => 'radio',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'off',
						'label' => esc_html__( 'Off', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'persen',
						'label' => esc_html__( 'Persentase (% dari subtotal)', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'nominal',
						'label' => esc_html__( 'Nominal (biaya tambahan fix)', 'themefood' ),
						'src'   => '',
					),
				),
			),
			array(
				'id'           => 'label_fee',
				'label'        => esc_html__( 'Label Biaya', 'themefood' ),
				'desc'         => esc_html__( 'Misal: Biaya Packing, Biaya COD, Additional Fee, Handling Fee. Default: Biaya Tambahan.', 'themefood' ),
				'std'          => 'Biaya Tambahan',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'additional_fee:is(persen),additional_fee:is(nominal)',
				'operator'     => 'or',
			),
			array(
				'id'           => 'persen_fee',
				'label'        => esc_html__( 'Persentase Biaya (%)', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan persentase biaya tambahan (dihitung dari subtotal)', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'additional_fee:is(persen)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'nominal_fee',
				'label'        => esc_html__( 'Nominal Biaya (' . $currency_sym . ')', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan nominal biaya tambahan', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'additional_fee:is(nominal)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_pembayaran',
				'label'        => esc_html__( 'Info Pembayaran', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_transferbank',
				'label'        => esc_html__( 'Transfer Bank', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'data_bank',
				'label'        => esc_html__( 'Data Bank', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan informasi data bank jika anda mengaktifkan metode pembayaran via Transfer Bank', 'themefood' ),
				'std'          => '',
				'type'         => 'list-item',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'settings'     => array( 
					array(
						'id'           => 'bank_name',
						'label'        => esc_html__( 'Nama Bank', 'themefood' ),
						'desc'         => '',
						'std'          => '',
						'type'         => 'text',
						'rows'         => '',
						'post_type'    => '',
						'taxonomy'     => '',
						'min_max_step' => '',
						'class'        => '',
						'condition'    => '',
						'operator'     => 'and',
					),
					array(
						'id'           => 'bank_number',
						'label'        => esc_html__( 'No Rekening', 'themefood' ),
						'desc'         => '',
						'std'          => '',
						'type'         => 'text',
						'rows'         => '',
						'post_type'    => '',
						'taxonomy'     => '',
						'min_max_step' => '',
						'class'        => '',
						'condition'    => '',
						'operator'     => 'and',
					),
					array(
						'id'           => 'bank_owner',
						'label'        => esc_html__( 'Nama Pemilik', 'themefood' ),
						'desc'         => '',
						'std'          => '',
						'type'         => 'text',
						'rows'         => '',
						'post_type'    => '',
						'taxonomy'     => '',
						'min_max_step' => '',
						'class'        => '',
						'condition'    => '',
						'operator'     => 'and',
					),
				),
			),
			array(
				'id'           => 'instruksi_transfer_bank',
				'label'        => esc_html__( 'Instruksi Transfer', 'themefood' ),
				'desc'         => esc_html__( '<strong>Opsional</strong>. Masukkan instruksi singkat terkait tata cara metode pembayaran via Transfer Bank', 'themefood' ),
				'std'          => 'Pembayaran dilakukan dengan cara transfer ke rekening yang tertera sesuai dengan nominal belanja.',
				'type'         => 'textarea-simple',
				'section'      => 'checkout',
				'rows'         => '3',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_cod',
				'label'        => esc_html__( 'COD (Cash On Delivery)', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'instruksi_cod',
				'label'        => esc_html__( 'Instruksi COD', 'themefood' ),
				'desc'         => esc_html__( '<strong>Opsional</strong>. Masukkan instruksi singkat terkait tata cara metode pembayaran via COD', 'themefood' ),
				'std'          => 'Pembayaran dilakukan dengan cara COD (Cash On Delivery). Gunakan uang pas untuk mempermudah pembayaran.',
				'type'         => 'textarea-simple',
				'section'      => 'checkout',
				'rows'         => '3',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_kasir',
				'label'        => esc_html__( 'Bayar di Kasir', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'instruksi_bayar_di_kasir',
				'label'        => esc_html__( 'Instruksi Bayar', 'themefood' ),
				'desc'         => esc_html__( '<strong>Opsional</strong>. Masukkan instruksi singkat terkait tata cara metode bayar di kasir', 'themefood' ),
				'std'          => 'Pembayaran dilakukan langsung di kasir yang tersedia.',
				'type'         => 'textarea-simple',
				'section'      => 'checkout',
				'rows'         => '3',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_durianpay',
				'label'        => esc_html__( 'DurianPay', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),			
			array(
				'id'           => 'deskripsi_durianpay',
				'label'        => esc_html__( 'Deskripsi Durianpay', 'themefood' ),
				'desc'         => esc_html__( 'Payment gateway dengan proses registrasi yang mudah dan mendukung beragam metode pembayaran mulai dari E-Wallet (Dana, OVO, LinkAja, ShopeePay), Virtual Account (BCA, Mandiri, BRI, BNI, Permata), dan Kartu Kredit / Debit. <a href="https://durianpay.id/?utm_source=themefood" target="_blank">Pelajari lebih lanjut</a>.<br><a href="https://dashboard.durianpay.id/?#/settings/webhooks/new" target="_blank">Webhook URL</a>: <code>https://demo.themefood.id/?gateway=durianpay</code>', 'themefood' ),
				'std'          => '',
				'type'         => 'textblock',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'subtitle_durianpay',
				'label'        => esc_html__( 'Alias', 'themefood' ),
				'desc'         => esc_html__( '<strong>Opsional</strong>. Masukkan nama alias untuk payment gateway DurianPay. Misal: E-Wallet, Virtual Account, dsb.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'api_durianpay',
				'label'        => esc_html__( 'API Key', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan api key (LIVE) layanan DurianPay. Klik <a href="https://dashboard.durianpay.id/?#/settings?activeTab=apiKeys" target="_blank">disini</a> untuk mendapatkannya.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'instruksi_durianpay',
				'label'        => esc_html__( 'Instruksi Bayar', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan instruksi singkat terkait tata cara metode pembayaran menggunakan DurianPay.', 'themefood' ),
				'std'          => 'Pembayaran menggunakan E-Wallet (Dana, OVO, LinkAja, ShopeePay), Virtual Account (BCA, Mandiri, BRI, BNI, Permata), dan Kartu Kredit / Debit.',
				'type'         => 'textarea-simple',
				'section'      => 'checkout',
				'rows'         => '3',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'durianpay_status',
				'label'        => esc_html__( 'Status Berhasil', 'themefood' ),
				'desc'         => esc_html__( 'Ubah status orderan yang berhasil setelah menemukan orderan yang telah dibayar.', 'themefood' ),
				'std'          => 'diproses',
				'type'         => 'select',
				'section'      => 'checkout',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'diproses',
						'label' => esc_html__( 'Diproses', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'diantar',
						'label' => esc_html__( 'Diantar', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'selesai',
						'label' => esc_html__( 'Selesai', 'themefood' ),
						'src'   => '',
					)
				),
			),
			array(
				'id'           => 'tab_notifikasi',
				'label'        => esc_html__( 'Notifikasi', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'follow_up',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'order_diproses',
				'label'        => esc_html__( 'Order Diproses', 'themefood' ),
				'desc'         => '',
				'std'          => '*Halo kak [nama]* 🖐

Selamat! Order kamu dengan ID #[id] sudah kami *proses*.
*Berikut ringkasan pesananmu:*
[produk]

🛵 *Ongkir:* [ongkir]
🏷 *Diskon:* [diskon]
💰 *Total:* [total]

Terima kasih 🙏
Kamu juga bisa melihat update status pemesanan pada *struk orderan* di link berikut: [struk]',
				'type'         => 'textarea-simple',
				'section'      => 'follow_up',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'order_diantar',
				'label'        => esc_html__( 'Order Diantar', 'themefood' ),
				'desc'         => '',
				'std'          => '*Halo kak [nama]* 🖐

Order kamu dengan ID #[id] sudah *diantar*. Selamat menunggu ya ❤

Terima kasih 🙏
Kamu juga bisa melihat update status pemesanan pada *struk orderan* di link berikut: [struk]',
				'type'         => 'textarea-simple',
				'section'      => 'follow_up',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'order_selesai',
				'label'        => esc_html__( 'Order Selesai', 'themefood' ),
				'desc'         => '',
				'std'          => '*Halo kak [nama]* 🖐

Order kamu dengan ID #[id] sudah *selesai*. 🎉

Terima kasih telah melakukan pemesanan. Sampai bertemu kembali di lain kesempatan 🙏',
				'type'         => 'textarea-simple',
				'section'      => 'follow_up',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'order_dibatalkan',
				'label'        => esc_html__( 'Order Dibatalkan', 'themefood' ),
				'desc'         => '',
				'std'          => '*Halo kak [nama]* 🖐

Sayang sekali status order kamu dengan ID #[id] sudah *dibatalkan*. Jika ada kendala atau pertanyaan terkait produk, pemesanan ataupun pembayaran jangan sungkat untuk *balas chat ini* ya kak.

Semoga kita bertemu kembali di lain kesempatan 🙏😢',
				'type'         => 'textarea-simple',
				'section'      => 'follow_up',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_followup',
				'label'        => esc_html__( 'Follow Up', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'follow_up',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'order_diterima_1',
				'label'        => esc_html__( 'Follow-Up Order Diterima #1', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textarea-simple',
				'section'      => 'follow_up',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'order_diterima_waktu_1',
				'label'        => esc_html__( 'Follow-Up Setelah (Jam)', 'themefood' ),
				'desc'         => 'Kirim pesan follow-up #1 setelah __ jam',
				'std'          => '',
				'type'         => 'text',
				'section'      => 'follow_up',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'order_diterima_2',
				'label'        => esc_html__( 'Follow-Up Order Diterima #2', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textarea-simple',
				'section'      => 'follow_up',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'order_diterima_waktu_2',
				'label'        => esc_html__( 'Follow-Up Setelah (Jam)', 'themefood' ),
				'desc'         => 'Kirim pesan follow-up #2 setelah __ jam',
				'std'          => '',
				'type'         => 'text',
				'section'      => 'follow_up',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'order_diterima_3',
				'label'        => esc_html__( 'Follow-Up Order Diterima #3', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textarea-simple',
				'section'      => 'follow_up',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),			
			array(
				'id'           => 'order_diterima_waktu_3',
				'label'        => esc_html__( 'Follow-Up Setelah (Jam)', 'themefood' ),
				'desc'         => 'Kirim pesan follow-up #3 setelah __ jam',
				'std'          => '',
				'type'         => 'text',
				'section'      => 'follow_up',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_integrasi',
				'label'        => esc_html__( 'Integrasi API', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'follow_up',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_botwhatsapp',
				'label'        => esc_html__( 'Integrasi BOT', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'follow_up',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'bot_service',
				'label'        => esc_html__( 'Layanan Bot WhatsApp', 'themefood' ),
				'desc'         => esc_html__( 'Pilih layanan bot penyedia API WhatsApp', 'themefood' ),
				'std'          => '',
				'type'         => 'select',
				'section'      => 'follow_up',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'http://send.woonotif.com/api/async_send_message',
						'label' => esc_html__( 'WooNotif', 'themefood' ),
						'src'   => '',
					)
				),
			),
			array(
				'id'           => 'token_key',
				'label'        => esc_html__( 'Token Key', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan token key layanan untuk auto follow-up via WhatsApp. <strong>KOSONGKAN</strong> untuk menonaktifkan fitur.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'follow_up',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_linkfollowup',
				'label'        => esc_html__( 'Link FU WhatsApp', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'follow_up',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'link_followup',
				'label'        => esc_html__( 'Link Follow Up', 'themefood' ),
				'desc'         => esc_html__( 'Pilih tujuan link ketika klik tombol Follow Up secara manual di menu Orderan', 'themefood' ),
				'std'          => '',
				'type'         => 'select',
				'section'      => 'follow_up',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
				'choices'      => array(
					array(
						'value' => 'web',
						'label' => esc_html__( 'WhatsApp WEB', 'themefood' ),
						'src'   => '',
					),
					array(
						'value' => 'api',
						'label' => esc_html__( 'WhatsApp Desktop', 'themefood' ),
						'src'   => '',
					)
				),
			),
			array(
				'id'           => 'background_struk',
				'label'        => esc_html__( 'Background Struk', 'themefood' ),
				'desc'         => esc_html__( 'Kustomisasi background untuk halaman struk online dan halaman order redirect.', 'themefood' ),
				'std'          => '',
				'type'         => 'background',
				'section'      => 'struk',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'deskripsi_salespop',
				'label'        => esc_html__( 'Deskripsi Salespop', 'themefood' ),
				'desc'         => esc_html__( 'Tampilkan notifikasi popup 10 orderan terakhir dengan mengaktifkan Sales Popup.', 'themefood' ),
				'std'          => '',
				'type'         => 'textblock',
				'section'      => 'sales_popup',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'aktifkan_salespop',
				'label'        => esc_html__( 'Aktifkan Sales Popup', 'themefood' ),
				'desc'         => esc_html__( 'Aktif / Nonaktifkan fitur Sales Popup pada halaman Katalog', 'themefood' ),
				'std'          => 'off',
				'type'         => 'on-off',
				'section'      => 'sales_popup',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'interval_salespop',
				'label'        => esc_html__( 'Interval Popup', 'themefood' ),
				'desc'         => esc_html__( 'Tentukan interval kemunculan popup dalam detik', 'themefood' ),
				'std'          => '10',
				'type'         => 'numeric-slider',
				'section'      => 'sales_popup',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '5,15,1',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'aktifkan_pwa',
				'label'        => esc_html__( 'Aktifkan PWA', 'themefood' ),
				'desc'         => esc_html__( 'Aktif / Nonaktifkan fitur Progressive Web App (PWA) yang membuat website semakin cepat dan dapat diakses secara offline', 'themefood' ),
				'std'          => 'off',
				'type'         => 'on-off',
				'section'      => 'pwa',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'theme_color',
				'label'        => esc_html__( 'Theme Color', 'themefood' ),
				'desc'         => esc_html__( 'Pilih warna tema PWA', 'themefood' ),
				'std'          => '#ffffff',
				'type'         => 'colorpicker',
				'section'      => 'pwa',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'background_color',
				'label'        => esc_html__( 'Background Color', 'themefood' ),
				'desc'         => esc_html__( 'Pilih warna background PWA', 'themefood' ),
				'std'          => '#ffffff',
				'type'         => 'colorpicker',
				'section'      => 'pwa',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'icon_pwa',
				'label'        => esc_html__( 'Icon PWA', 'themefood' ),
				'desc'         => esc_html__( 'Upload icon berukuran 512x512 pixels', 'themefood' ),
				'std'          => '',
				'type'         => 'upload',
				'section'      => 'pwa',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'footer_katalog_produk',
				'label'        => esc_html__( 'Katalog Produk', 'themefood' ),
				'desc'         => esc_html__( 'Gunakan tag <strong>script</strong> secara lengkap jika ingin memasang kode javascript', 'themefood' ),
				'std'          => '',
				'type'         => 'textarea-simple',
				'section'      => 'kode_footer',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'footer_order_redirect',
				'label'        => esc_html__( 'Order Redirect', 'themefood' ),
				'desc'         => esc_html__( 'Gunakan tag <strong>script</strong> secara lengkap jika ingin memasang kode javascript', 'themefood' ),
				'std'          => '',
				'type'         => 'textarea-simple',
				'section'      => 'kode_footer',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_admin',
				'label'        => esc_html__( 'Admin Theme', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'admin_theme',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'aktifkan_admintheme',
				'label'        => esc_html__( 'Aktifkan Tema Admin', 'themefood' ),
				'desc'         => esc_html__( 'Aktif / Nonaktifkan tampilan custom admin theme ala ThemeFood', 'themefood' ),
				'std'          => 'off',
				'type'         => 'on-off',
				'section'      => 'admin_theme',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_adminnotif',
				'label'        => esc_html__( 'Admin Notification', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'admin_theme',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'aktifkan_adminnotif',
				'label'        => esc_html__( 'Aktifkan Notifikasi Order', 'themefood' ),
				'desc'         => esc_html__( 'Aktif / Nonaktifkan notifikasi order baru (membutuhkan API OneSignal).', 'themefood' ),
				'std'          => 'off',
				'type'         => 'on-off',
				'section'      => 'admin_theme',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'onesignal_appid',
				'label'        => esc_html__( 'OneSignal App ID', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan App ID OneSignal yang bisa anda dapatkan di <a href="https://documentation.onesignal.com/docs/accounts-and-keys" target="_blank">halaman setting OneSignal</a>.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'admin_theme',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'aktifkan_adminnotif:is(on)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'onesignal_apikey',
				'label'        => esc_html__( 'OneSignal API Key', 'themefood' ),
				'desc'         => esc_html__( 'Masukkan REST API Key OneSignal yang bisa anda dapatkan di <a href="https://documentation.onesignal.com/docs/accounts-and-keys" target="_blank">halaman setting OneSignal</a>.', 'themefood' ),
				'std'          => '',
				'type'         => 'text',
				'section'      => 'admin_theme',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => 'aktifkan_adminnotif:is(on)',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_adminwidget',
				'label'        => esc_html__( 'Admin Widget', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'admin_theme',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'aktifkan_adminwidget',
				'label'        => esc_html__( 'Aktifkan Widget Laporan', 'themefood' ),
				'desc'         => esc_html__( 'Aktif / Nonaktifkan widget laporan di dashboard WP Admin (akan menghapus widget lainnya).', 'themefood' ),
				'std'          => 'off',
				'type'         => 'on-off',
				'section'      => 'admin_theme',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'title_form',
				'label'        => esc_html__( 'Form Order Generator', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'textblock-titled',
				'section'      => 'form_order',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'form_generator',
				'label'        => esc_html__( 'Pilih Produk', 'themefood' ),
				'desc'         => esc_html__( 'Pilih atau ketik nama produk yang akan dimasukkan ke dalam form order.', 'themefood' ),
				'std'          => '',
				'type'         => 'custom-post-type-select',
				'section'      => 'form_order',
				'rows'         => '',
				'post_type'    => 'tf-produk',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'form_shortcode',
				'label'        => esc_html__( 'Shortcode', 'themefood' ),
				'desc'         => esc_html__( 'Gunakan kode shortcode di atas untuk menampilkan form order.', 'themefood' ),
				'std'          => '[tf_form id=""]',
				'type'         => 'textarea-simple',
				'section'      => 'form_order',
				'rows'         => '5',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'tab_format',
				'label'        => esc_html__( 'Format', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'bantuan',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'list_format',
				'label'        => esc_html__( 'List Format', 'themefood' ),
				'desc'         => esc_html__( 'Berikut adalah referensi ukuran format gambar yang digunakan ThemeFood:<br>
<p style="margin: 10px 0!important;"><strong>Foto CS ( 112 x 112 px )</strong></p>
<img style="max-width: 100%;" src="https://via.placeholder.com/112x112" />
<p style="margin: 10px 0!important;"><strong>Kategori Produk ( 200 x 87 px )</strong></p>
<img style="max-width: 100%;" src="https://via.placeholder.com/200x87" />
<p style="margin: 10px 0!important;"><strong>Info Toko ( 555 x 315 px )</strong></p>
<img style="max-width: 100%;" src="https://via.placeholder.com/555x315" />
<p style="margin: 10px 0!important;"><strong>Katalog Produk ( 555 x 555 px )</strong></p>
<img style="max-width: 100%;" src="https://via.placeholder.com/555x555" />
<p style="margin: 10px 0!important;"><strong>Foto Slider ( 940 x 546 px )</strong></p>
<img style="max-width: 100%;" src="https://via.placeholder.com/950x546" />', 'themefood' ),
				'std'          => '',
				'type'         => 'textblock',
				'section'      => 'bantuan',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),	
			array(
				'id'           => 'tab_shortcode',
				'label'        => esc_html__( 'Shortcode', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'bantuan',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'list_shortcode',
				'label'        => esc_html__( 'List Shortcode', 'themefood' ),
				'desc'         => esc_html__( 'Berikut adalah shortcode yang bisa anda gunakan dalam menyusun format order dan format follow-up pada halaman ini:<br>
<ul>
<li><strong>[id]</strong> ID Orderan</li>
<li><strong>[nama]</strong> Nama Lengkap Customer</li>
<li><strong>[nowa]</strong> No WhatsApp Customer</li>
<li><strong>[email]</strong> Alamat Email Customer</li>
<li><strong>[alamat]</strong> Alamat Lengkap Customer</li>
<li><strong>[kecamatan]</strong> Kecamatan Customer</li>
<li><strong>[lokasi]</strong> Link Maps Lokasi Customer</li>
<li><strong>[meja]</strong> No Meja Customer (Untuk Dine In)</li>
<li><strong>[produk]</strong> List Produk yang Dipesan</li>
<li><strong>[subtotal]</strong> Jumlah Subtotal Orderan</li>
<li><strong>[ongkir]</strong> Ongkos Kirim Orderan</li>
<li><strong>[diskon]</strong> Diskon yang Digunakan</li>
<li><strong>[unik]</strong> Kode Unik Orderan</li>
<li><strong>[fee]</strong> Additional Fee</li>
<li><strong>[delivtime]</strong> Delivery Date & Time</li>
<li><strong>[total]</strong> Jumlah Total Orderan</li>
<li><strong>[pembayaran]</strong> Metode Pembayaran yang Dipilih</li>
<li><strong>[instruksi]</strong> Instruksi Pembayaran Sesuai Metode yang Dipilih</li>
<li><strong>[struk]</strong> Link Struk Orderan</li>
</ul>', 'themefood' ),
				'std'          => '',
				'type'         => 'textblock',
				'section'      => 'bantuan',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),			
			array(
				'id'           => 'tab_template',
				'label'        => esc_html__( 'Template', 'themefood' ),
				'desc'         => '',
				'std'          => '',
				'type'         => 'tab',
				'section'      => 'bantuan',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'desc_template',
				'label'        => esc_html__( 'Deskripsi Template', 'themefood' ),
				'desc'         => esc_html__( 'Berikut adalah file template yang bisa anda gunakan untuk import & export data di menu WP Imp Exp. Klik pada template export import yang dipilih untuk download. Anda dapat upload template pada halaman Setting <a href="'.get_admin_url().'admin.php?page=wpie-settings">Manage Templates</a>.', 'themefood' ),
				'std'          => '',
				'type'         => 'textblock',
				'section'      => 'bantuan',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),
			array(
				'id'           => 'list_impexp',
				'label'        => esc_html__( 'List Import Export', 'themefood' ),
				'desc'         => esc_html__( '<ul>
<li><strong><a href="https://themefood.id/dl/template/export-data-orderan.txt" target="_blank" download>[EXPORT]</a></strong> Template Data Orderan</li>
<li><strong><a href="https://themefood.id/dl/template/import-katalog-produk.txt" target="_blank" download>[IMPORT]</a></strong> Template Katalog Produk</li>
<li><strong><a href="https://themefood.id/dl/template/sample-katalog-produk.xlsx" target="_blank" download>[SAMPLE]</a></strong> Excel Katalog Produk</li>
</ul>', 'themefood' ),
				'std'          => '',
				'type'         => 'textblock',
				'section'      => 'bantuan',
				'rows'         => '',
				'post_type'    => '',
				'taxonomy'     => '',
				'min_max_step' => '',
				'class'        => '',
				'condition'    => '',
				'operator'     => 'and',
			),			
		)
	);

	// Allow settings to be filtered before saving.
	$custom_settings = apply_filters( ot_settings_id() . '_args', $custom_settings );

	// Settings are not the same update the DB.
	if ( $saved_settings !== $custom_settings ) {
		update_option( ot_settings_id(), $custom_settings ); 
	}

	// Lets OptionTree know the UI Builder is being overridden.
	global $ot_has_custom_theme_options;
	$ot_has_custom_theme_options = true;
}
